import './App.css'
import {PlayersContext} from "./api/contexts/PlayersContext.tsx";
import type IPlayer from "./api/types/IPlayer.ts";
import {useEffect, useState} from "react";
import type IGame from "./api/types/IGame.ts";
import {GamesContext} from "./api/contexts/GamesContext.tsx";
import {ApiUriContext} from "./api/fetchApi.tsx";
import {GetGames, GetPlayers} from "./api/endpoints/Data.tsx";
import {
  AccordionGroup,
  Box,
  Divider,
  Input,
  Stack,
  Typography
} from "@mui/joy";
import GameAccordionItem from "./components/GameAccordionItem.tsx";
import PlayerAccordionItem from "./components/PlayerAccordionItem.tsx";
import StatsDrawer from "./components/StatsDrawer.tsx";

export default function App() {
  const [apiUri, setApiUri] = useState<string>("http://localhost:5239");
  const [players, setPlayers] = useState<IPlayer[]>([]);
  const [games, setGames] = useState<IGame[]>([]);

  const [selectedPlayer, setSelectedPlayer] = useState<IPlayer | null>(null);
  const [selectedGame, setSelectedGame] = useState<IGame | null>(null);
  const [open, setOpen] = useState<boolean>(false);

  const OpenDrawer = (player: IPlayer, game: IGame) => {
    setSelectedPlayer(player);
    setSelectedGame(game);
    setOpen(true);
  }

  useEffect(() => {
    GetPlayers(apiUri).then(setPlayers);
    GetGames(apiUri).then(setGames);
  }, [apiUri]);

  return (
      <ApiUriContext value={apiUri}>
        <PlayersContext.Provider value={{players: players}}>
          <GamesContext value={{games: games}}>
            <Input type={"text"} placeholder={"Api Uri"} value={apiUri} onChange={(e) => setApiUri(e.target.value)} />
            <Stack direction={"row"} spacing={2}>
              <Box sx={{width:'50%'}}>
                <Typography level={"h2"}>Players</Typography>
                <AccordionGroup>
                  {players?.map((player) => <PlayerAccordionItem key={player.steamId} player={player} OpenDrawer={OpenDrawer} />)}
                </AccordionGroup>
              </Box>
              <Divider />
              <Box sx={{width:'50%'}}>
                <Typography level={"h2"}>Games</Typography>
                <AccordionGroup>
                  {games?.map((game) => <GameAccordionItem key={game.appId} game={game} OpenDrawer={OpenDrawer} />)}
                </AccordionGroup>
              </Box>
            </Stack>
            <StatsDrawer player={selectedPlayer} game={selectedGame} open={open} setOpen={setOpen} />
          </GamesContext>
        </PlayersContext.Provider>
      </ApiUriContext>
  )
}
