import type IGame from "../api/types/IGame.ts";
import {
    Accordion,
    AccordionDetails,
    AccordionSummary,
    Stack
} from "@mui/joy";
import type IPlayer from "../api/types/IPlayer.ts";
import {useContext, useEffect, useState} from "react";
import {GetPlayersOfGame} from "../api/endpoints/Data.tsx";
import {ApiUriContext} from "../api/fetchApi.tsx";
import PlayerCard from "./PlayerCard.tsx";

export default function GameAccordionItem({game, OpenDrawer} : {game: IGame, OpenDrawer : (player: IPlayer, game: IGame) => void}) {
    const apiUri = useContext(ApiUriContext);

    const [players, setPlayers] = useState<IPlayer[]>([]);
    const [expanded, setExpanded] = useState<boolean>(false);

    useEffect(() => {
        if(!expanded)
            return;
        GetPlayersOfGame(apiUri, game.appId).then(setPlayers);
    }, [expanded]);

    return (
        <Accordion key={game.appId} onChange={(_, expanded) => setExpanded(expanded)}>
            <AccordionSummary>{game.name}</AccordionSummary>
            <AccordionDetails>
                <Stack flexWrap={"wrap"} direction={"row"} useFlexGap={true} spacing={1}>
                    {players?.map((player) => <PlayerCard player={player} onClick={() => OpenDrawer(player, game)} />)}
                </Stack>
            </AccordionDetails>
        </Accordion>
    );
}