import type IPlayer from "../api/types/IPlayer.ts";
import type IGame from "../api/types/IGame.ts";
import {DialogContent, DialogTitle, Drawer, ModalClose, Typography} from "@mui/joy";
import {type Dispatch, useContext, useEffect, useState} from "react";
import {ApiUriContext} from "../api/fetchApi.tsx";
import {GetTimelineGame} from "../api/endpoints/TimeTrack.tsx";
import type ITrackedTime from "../api/types/ITrackedTime.ts";
import {LineChart} from "@mui/x-charts";
import PlayerCard from "./PlayerCard.tsx";

export default function StatsDrawer({player, game, open, setOpen} : {player: IPlayer | null, game: IGame | null, open: boolean, setOpen: Dispatch<boolean>}) {

    const apiUri = useContext(ApiUriContext);

    const [trackedTime, setTrackedTime] = useState<ITrackedTime[]>();

    useEffect(() => {
        if(!open || !game || !player)
            return;
        GetTimelineGame(apiUri, player.steamId, game.appId).then(setTrackedTime);
    }, [open]);

    return (
        <Drawer anchor={"bottom"} size={"lg"} open={open} onClose={() => setOpen(false)}>
            <ModalClose />
            <DialogTitle>
                <Typography level={"h4"} alignContent={"center"}>{game?.name}</Typography>
                <PlayerCard player={player} />
            </DialogTitle>
            <DialogContent>
                <LineChart xAxis={[{data : trackedTime?.map(t => t.timeStamp)??[], scaleType: "utc", label: "Date"}]}
                           series={[{data: trackedTime?.map(t => Number(t.timePlayed))??[], label: "Minutes Played"}]}
                           sx={{height: "80%"}}/>
            </DialogContent>
        </Drawer>
    );
}